| Title: | Viewing Observational Health Data Sciences and Informatics Results via 'shiny' Modules |
|---|---|
| Description: | Users can build a single 'shiny' app for exploring population characterization, population-level causal effect estimation, and patient-level prediction results generated via the R analyses packages in 'HADES' (see <https://ohdsi.github.io/Hades/>). Learn more about 'OhdsiShinyAppBuilder' at <https://ohdsi.github.io/OhdsiShinyAppBuilder/>. |
| Authors: | Jenna Reps [aut, cre], Nathan Hall [aut], Josh Ide [aut], Jamie Gibert [aut] |
| Maintainer: | Jenna Reps <[email protected]> |
| License: | Apache License 2.0 |
| Version: | 1.1.0 |
| Built: | 2026-07-22 19:07:31 UTC |
| Source: | https://github.com/cran/OhdsiShinyAppBuilder |
Create an R list with the config specification for one or more modules
addModuleConfig(config, moduleConfig)addModuleConfig(config, moduleConfig)
config |
The current config to append the extra module to |
moduleConfig |
A module config to be added |
User specifies the settings to create a config for a module
An R list with the module config settings
Other Config:
initializeModuleConfig(),
loadConfig(),
saveConfig()
Create an R list with the about config specification
createDefaultAboutConfig()createDefaultAboutConfig()
User specifies the settings to create a default config for an about module
An R list with the module config settings
Other ModuleConfig:
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the characterization config specification
createDefaultCharacterizationConfig()createDefaultCharacterizationConfig()
User specifies the settings to create a default config for a characterization module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the characterization config specification
createDefaultCohortDiagnosticsConfig()createDefaultCohortDiagnosticsConfig()
User specifies the settings to create a default config for a characterization module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the cohort generator config specification
createDefaultCohortGeneratorConfig()createDefaultCohortGeneratorConfig()
User specifies the settings to create a default config for a cohort generator module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the cohort method config specification (depreciated)
createDefaultCohortMethodConfig()createDefaultCohortMethodConfig()
User specifies the settings to create a default config for a cohort method module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the datasources config specification
createDefaultDatasourcesConfig()createDefaultDatasourcesConfig()
User specifies the settings to create a default config for a datasources module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the estimation config specification
createDefaultEstimationConfig()createDefaultEstimationConfig()
User specifies the settings to create a default config for an estimation module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the Evidence Synthesis config specification (depreciated)
createDefaultEvidenceSynthesisConfig()createDefaultEvidenceSynthesisConfig()
User specifies the settings to create a default config for a Evidence Synthesis module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the about config specification
createDefaultHomeConfig()createDefaultHomeConfig()
User specifies the settings to create a default config for an about module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the phevaluator config specification
createDefaultPhevaluatorConfig()createDefaultPhevaluatorConfig()
User specifies the settings to create a default config for a phevaluator module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the prediction config specification
createDefaultPredictionConfig()createDefaultPredictionConfig()
User specifies the settings to create a default config for a prediction module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the report config specification
createDefaultReportConfig()createDefaultReportConfig()
User specifies the settings to create a default config for a report module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Create an R list with the default table prefixes and tables
createDefaultResultDatabaseSettings( schema = "main", vocabularyDatabaseSchema = schema, cgTablePrefix = "cg_", cgTable = "cohort_definition", databaseTable = "DATABASE_META_DATA", databaseTablePrefix = "", cdTablePrefix = "cd_", cTablePrefix = "c_", incidenceTablePrefix = "ci_", plpTablePrefix = "plp_", cmTablePrefix = "cm_", sccsTablePrefix = "sccs_", esTablePrefix = "es_", pvTablePrefix = "pv_" )createDefaultResultDatabaseSettings( schema = "main", vocabularyDatabaseSchema = schema, cgTablePrefix = "cg_", cgTable = "cohort_definition", databaseTable = "DATABASE_META_DATA", databaseTablePrefix = "", cdTablePrefix = "cd_", cTablePrefix = "c_", incidenceTablePrefix = "ci_", plpTablePrefix = "plp_", cmTablePrefix = "cm_", sccsTablePrefix = "sccs_", esTablePrefix = "es_", pvTablePrefix = "pv_" )
schema |
The schema containing the OHDSI study results |
vocabularyDatabaseSchema |
The schema containing the vocabulary database |
cgTablePrefix |
The table prefix for cohort generator tables |
cgTable |
The table with the cohort definitions in cohort generator |
databaseTable |
The table with the database details |
databaseTablePrefix |
The prefix for the databaseTable |
cdTablePrefix |
The table prefix for the cohort diagnostic results |
cTablePrefix |
The table prefix for the characterization results |
incidenceTablePrefix |
The table prefix for the incidence results |
plpTablePrefix |
The table prefix for the prediction results |
cmTablePrefix |
The table prefix for the cohort method results |
sccsTablePrefix |
The table prefix for the self controlled case series results |
esTablePrefix |
The table prefix for the evidence synthesis method results |
pvTablePrefix |
The table prefix for the phevaluator results |
User specifies the schema name and can override default table prefixes and table names
An R list with the module config settings
Create an R list with the SCCS config specification (depreciated)
createDefaultSccsConfig()createDefaultSccsConfig()
User specifies the settings to create a default config for a SCCS module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createModuleConfig()
Create an R list with the config specification
createModuleConfig( moduleId = "about", tabName = "About", shinyModulePackage = "OhdsiShinyModules", shinyModulePackageVersion = "3.0.0", moduleUiFunction = "aboutViewer", moduleServerFunction = "aboutServer", moduleInfoBoxFile = "aboutHelperFile()", moduleIcon = "info", installSource = "CRAN", gitHubRepo = NULL )createModuleConfig( moduleId = "about", tabName = "About", shinyModulePackage = "OhdsiShinyModules", shinyModulePackageVersion = "3.0.0", moduleUiFunction = "aboutViewer", moduleServerFunction = "aboutServer", moduleInfoBoxFile = "aboutHelperFile()", moduleIcon = "info", installSource = "CRAN", gitHubRepo = NULL )
moduleId |
The shiny id for the tab containing the module UI |
tabName |
The name of the tab in the shiny app (this will be the side menu button text) |
shinyModulePackage |
The R package to find the server and UI functions |
shinyModulePackageVersion |
The minimum version of the shinyModulePackage |
moduleUiFunction |
The name of the UI function in the R package shinyModulePackage |
moduleServerFunction |
The name of the server function in the R package shinyModulePackage |
moduleInfoBoxFile |
The function in the R package shinyModulePackage that contains info text |
moduleIcon |
The icon to use for the side menu button |
installSource |
Either CRAN or github specifying where to install shinyModulePackage from |
gitHubRepo |
If installSource is github then this is the github repo containing the package e.g., 'ohdsi' |
User specifies the settings to create a config for a module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig()
Create a shiny app for a shiny server
createShinyApp( config, connection, resultDatabaseSettings = createDefaultResultDatabaseSettings(), connectionDetails = NULL, usePooledConnection = TRUE, studyDescription = NULL, title = "OHDSI Analysis Viewer", protocolLink = "http://ohdsi.org", themePackage = "OhdsiShinyAppBuilder", htmlHeader = "", reportSummaryDetails = NULL )createShinyApp( config, connection, resultDatabaseSettings = createDefaultResultDatabaseSettings(), connectionDetails = NULL, usePooledConnection = TRUE, studyDescription = NULL, title = "OHDSI Analysis Viewer", protocolLink = "http://ohdsi.org", themePackage = "OhdsiShinyAppBuilder", htmlHeader = "", reportSummaryDetails = NULL )
config |
The json with the app config |
connection |
A connection to the results |
resultDatabaseSettings |
A list with the result schema and table prefixes |
connectionDetails |
A DatabaseConnector::connectionDetails connection to the results database |
usePooledConnection |
Use a pooled database connection or not - set to true for multi-user environments (default) |
studyDescription |
A human-readable character string describing the study/analysis |
title |
The title for the app. Defaults to: OHDSI Analysis Viewer |
protocolLink |
A link to a site containing the study protocol |
themePackage |
A package containing custom theme elements |
htmlHeader |
Additional HTML to add to the shiny app header |
reportSummaryDetails |
NULL or a data.frame with the columns reportName and reportLocation |
User specifies the json config and connection
Shiny app instance
Other Shiny:
viewShiny()
Creates an empty config
initializeModuleConfig()initializeModuleConfig()
An empty config that can be used to add shiny module configs to
An empty list
Other Config:
addModuleConfig(),
loadConfig(),
saveConfig()
Load the config specification
loadConfig(configLocation)loadConfig(configLocation)
configLocation |
The location of the config json file |
User specifies the config file and this function returns the R list with the config
An R list with the config settings
Other Config:
addModuleConfig(),
initializeModuleConfig(),
saveConfig()
A package for creating viewers for the OHDSI shiny apps
Maintainer: Jenna Reps [email protected]
Authors:
Jenna Reps [email protected]
Nathan Hall
Josh Ide
Jamie Gibert
Save the R list with the config specification as a json
saveConfig(configList, configLocation)saveConfig(configList, configLocation)
configList |
An R list with the config settings |
configLocation |
The location to save the config json file |
User saves the R list with the config as a json file
An R list with the config settings
Other Config:
addModuleConfig(),
initializeModuleConfig(),
loadConfig()
Open the shiny app
viewShiny( config, connection, resultDatabaseSettings = createDefaultResultDatabaseSettings(), connectionDetails = NULL, usePooledConnection = TRUE, studyDescription = NULL, title = "OHDSI Analysis Viewer", protocolLink = "http://ohdsi.org", themePackage = "OhdsiShinyAppBuilder", htmlHeader = "" )viewShiny( config, connection, resultDatabaseSettings = createDefaultResultDatabaseSettings(), connectionDetails = NULL, usePooledConnection = TRUE, studyDescription = NULL, title = "OHDSI Analysis Viewer", protocolLink = "http://ohdsi.org", themePackage = "OhdsiShinyAppBuilder", htmlHeader = "" )
config |
The json with the app config |
connection |
A connection to the results |
resultDatabaseSettings |
A list with the result schema and table prefixes |
connectionDetails |
A DatabaseConnector::connectionDetails connection to the results database |
usePooledConnection |
Use a pooled database connection or not - set to true for multi-user environments (default) |
studyDescription |
A human-readable character string describing the study/analysis |
title |
The title for the app. Defaults to: OHDSI Analysis Viewer |
protocolLink |
A link to a site containing the study protocol |
themePackage |
A package containing custom theme elements |
htmlHeader |
Additional HTML to add to the shiny app header |
User specifies the json config and connection
The shiny app will open
Other Shiny:
createShinyApp()