| Type: | Package |
| Title: | Viewing Observational Health Data Sciences and Informatics Results via 'shiny' Modules |
| Version: | 1.1.0 |
| Date: | 2026-07-22 |
| Maintainer: | Jenna Reps <jreps@its.jnj.com> |
| Description: | Users can build a single 'shiny' app for exploring population characterization, population-level causal effect estimation, and patient-level prediction results generated via the R analyses packages in 'HADES' (see https://ohdsi.github.io/Hades/). Learn more about 'OhdsiShinyAppBuilder' at https://ohdsi.github.io/OhdsiShinyAppBuilder/. |
| License: | Apache License 2.0 |
| VignetteBuilder: | knitr |
| Depends: | R (≥ 3.3.0) |
| Imports: | checkmate, DatabaseConnector, dplyr, ParallelLogger (≥ 2.0.0), remotes, ResultModelManager (≥ 0.5.0), rlang, shiny, shinydashboard, utils |
| Suggests: | devtools, Eunomia, jsonlite, knitr, rmarkdown, testthat, markdown |
| Encoding: | UTF-8 |
| Config/roxygen2/version: | 8.0.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-07-22 17:08:58 UTC; jreps |
| Author: | Jenna Reps [aut, cre], Nathan Hall [aut], Josh Ide [aut], Jamie Gibert [aut] |
| Repository: | CRAN |
| Date/Publication: | 2026-07-22 17:40:33 UTC |
OhdsiShinyAppBuilder
Description
A package for creating viewers for the OHDSI shiny apps
Author(s)
Maintainer: Jenna Reps jreps@its.jnj.com
Authors:
Jenna Reps jreps@its.jnj.com
Nathan Hall
Josh Ide
Jamie Gibert
addModuleConfig
Description
Create an R list with the config specification for one or more modules
Usage
addModuleConfig(config, moduleConfig)
Arguments
config |
The current config to append the extra module to |
moduleConfig |
A module config to be added |
Details
User specifies the settings to create a config for a module
Value
An R list with the module config settings
See Also
Other Config:
initializeModuleConfig(),
loadConfig(),
saveConfig()
createDefaultAboutConfig
Description
Create an R list with the about config specification
Usage
createDefaultAboutConfig()
Details
User specifies the settings to create a default config for an about module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultCharacterizationConfig
Description
Create an R list with the characterization config specification
Usage
createDefaultCharacterizationConfig()
Details
User specifies the settings to create a default config for a characterization module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultCohortDiagnosticsConfig
Description
Create an R list with the characterization config specification
Usage
createDefaultCohortDiagnosticsConfig()
Details
User specifies the settings to create a default config for a characterization module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultCohortGeneratorConfig
Description
Create an R list with the cohort generator config specification
Usage
createDefaultCohortGeneratorConfig()
Details
User specifies the settings to create a default config for a cohort generator module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultCohortMethodConfig
Description
Create an R list with the cohort method config specification (depreciated)
Usage
createDefaultCohortMethodConfig()
Details
User specifies the settings to create a default config for a cohort method module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultDatasourcesConfig
Description
Create an R list with the datasources config specification
Usage
createDefaultDatasourcesConfig()
Details
User specifies the settings to create a default config for a datasources module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultEstimationConfig
Description
Create an R list with the estimation config specification
Usage
createDefaultEstimationConfig()
Details
User specifies the settings to create a default config for an estimation module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultEvidenceSynthesisConfig
Description
Create an R list with the Evidence Synthesis config specification (depreciated)
Usage
createDefaultEvidenceSynthesisConfig()
Details
User specifies the settings to create a default config for a Evidence Synthesis module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultHomeConfig
Description
Create an R list with the about config specification
Usage
createDefaultHomeConfig()
Details
User specifies the settings to create a default config for an about module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultPhevaluatorConfig
Description
Create an R list with the phevaluator config specification
Usage
createDefaultPhevaluatorConfig()
Details
User specifies the settings to create a default config for a phevaluator module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultPredictionConfig
Description
Create an R list with the prediction config specification
Usage
createDefaultPredictionConfig()
Details
User specifies the settings to create a default config for a prediction module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultReportConfig
Description
Create an R list with the report config specification
Usage
createDefaultReportConfig()
Details
User specifies the settings to create a default config for a report module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultSccsConfig(),
createModuleConfig()
createDefaultResultDatabaseSettings
Description
Create an R list with the default table prefixes and tables
Usage
createDefaultResultDatabaseSettings(
schema = "main",
vocabularyDatabaseSchema = schema,
cgTablePrefix = "cg_",
cgTable = "cohort_definition",
databaseTable = "DATABASE_META_DATA",
databaseTablePrefix = "",
cdTablePrefix = "cd_",
cTablePrefix = "c_",
incidenceTablePrefix = "ci_",
plpTablePrefix = "plp_",
cmTablePrefix = "cm_",
sccsTablePrefix = "sccs_",
esTablePrefix = "es_",
pvTablePrefix = "pv_"
)
Arguments
schema |
The schema containing the OHDSI study results |
vocabularyDatabaseSchema |
The schema containing the vocabulary database |
cgTablePrefix |
The table prefix for cohort generator tables |
cgTable |
The table with the cohort definitions in cohort generator |
databaseTable |
The table with the database details |
databaseTablePrefix |
The prefix for the databaseTable |
cdTablePrefix |
The table prefix for the cohort diagnostic results |
cTablePrefix |
The table prefix for the characterization results |
incidenceTablePrefix |
The table prefix for the incidence results |
plpTablePrefix |
The table prefix for the prediction results |
cmTablePrefix |
The table prefix for the cohort method results |
sccsTablePrefix |
The table prefix for the self controlled case series results |
esTablePrefix |
The table prefix for the evidence synthesis method results |
pvTablePrefix |
The table prefix for the phevaluator results |
Details
User specifies the schema name and can override default table prefixes and table names
Value
An R list with the module config settings
createDefaultSccsConfig
Description
Create an R list with the SCCS config specification (depreciated)
Usage
createDefaultSccsConfig()
Details
User specifies the settings to create a default config for a SCCS module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createModuleConfig()
createModuleConfig
Description
Create an R list with the config specification
Usage
createModuleConfig(
moduleId = "about",
tabName = "About",
shinyModulePackage = "OhdsiShinyModules",
shinyModulePackageVersion = "3.0.0",
moduleUiFunction = "aboutViewer",
moduleServerFunction = "aboutServer",
moduleInfoBoxFile = "aboutHelperFile()",
moduleIcon = "info",
installSource = "CRAN",
gitHubRepo = NULL
)
Arguments
moduleId |
The shiny id for the tab containing the module UI |
tabName |
The name of the tab in the shiny app (this will be the side menu button text) |
shinyModulePackage |
The R package to find the server and UI functions |
shinyModulePackageVersion |
The minimum version of the shinyModulePackage |
moduleUiFunction |
The name of the UI function in the R package shinyModulePackage |
moduleServerFunction |
The name of the server function in the R package shinyModulePackage |
moduleInfoBoxFile |
The function in the R package shinyModulePackage that contains info text |
moduleIcon |
The icon to use for the side menu button |
installSource |
Either CRAN or github specifying where to install shinyModulePackage from |
gitHubRepo |
If installSource is github then this is the github repo containing the package e.g., 'ohdsi' |
Details
User specifies the settings to create a config for a module
Value
An R list with the module config settings
See Also
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig()
createShinyApp
Description
Create a shiny app for a shiny server
Usage
createShinyApp(
config,
connection,
resultDatabaseSettings = createDefaultResultDatabaseSettings(),
connectionDetails = NULL,
usePooledConnection = TRUE,
studyDescription = NULL,
title = "OHDSI Analysis Viewer",
protocolLink = "http://ohdsi.org",
themePackage = "OhdsiShinyAppBuilder",
htmlHeader = "",
reportSummaryDetails = NULL
)
Arguments
config |
The json with the app config |
connection |
A connection to the results |
resultDatabaseSettings |
A list with the result schema and table prefixes |
connectionDetails |
A DatabaseConnector::connectionDetails connection to the results database |
usePooledConnection |
Use a pooled database connection or not - set to true for multi-user environments (default) |
studyDescription |
A human-readable character string describing the study/analysis |
title |
The title for the app. Defaults to: OHDSI Analysis Viewer |
protocolLink |
A link to a site containing the study protocol |
themePackage |
A package containing custom theme elements |
htmlHeader |
Additional HTML to add to the shiny app header |
reportSummaryDetails |
NULL or a data.frame with the columns reportName and reportLocation |
Details
User specifies the json config and connection
Value
Shiny app instance
See Also
Other Shiny:
viewShiny()
initializeModuleConfig
Description
Creates an empty config
Usage
initializeModuleConfig()
Details
An empty config that can be used to add shiny module configs to
Value
An empty list
See Also
Other Config:
addModuleConfig(),
loadConfig(),
saveConfig()
loadConfig
Description
Load the config specification
Usage
loadConfig(configLocation)
Arguments
configLocation |
The location of the config json file |
Details
User specifies the config file and this function returns the R list with the config
Value
An R list with the config settings
See Also
Other Config:
addModuleConfig(),
initializeModuleConfig(),
saveConfig()
saveConfig
Description
Save the R list with the config specification as a json
Usage
saveConfig(configList, configLocation)
Arguments
configList |
An R list with the config settings |
configLocation |
The location to save the config json file |
Details
User saves the R list with the config as a json file
Value
An R list with the config settings
See Also
Other Config:
addModuleConfig(),
initializeModuleConfig(),
loadConfig()
viewShiny
Description
Open the shiny app
Usage
viewShiny(
config,
connection,
resultDatabaseSettings = createDefaultResultDatabaseSettings(),
connectionDetails = NULL,
usePooledConnection = TRUE,
studyDescription = NULL,
title = "OHDSI Analysis Viewer",
protocolLink = "http://ohdsi.org",
themePackage = "OhdsiShinyAppBuilder",
htmlHeader = ""
)
Arguments
config |
The json with the app config |
connection |
A connection to the results |
resultDatabaseSettings |
A list with the result schema and table prefixes |
connectionDetails |
A DatabaseConnector::connectionDetails connection to the results database |
usePooledConnection |
Use a pooled database connection or not - set to true for multi-user environments (default) |
studyDescription |
A human-readable character string describing the study/analysis |
title |
The title for the app. Defaults to: OHDSI Analysis Viewer |
protocolLink |
A link to a site containing the study protocol |
themePackage |
A package containing custom theme elements |
htmlHeader |
Additional HTML to add to the shiny app header |
Details
User specifies the json config and connection
Value
The shiny app will open
See Also
Other Shiny:
createShinyApp()